==> estateplat-common-1.2.3-20180202.065337-24-sources.jar: cn/gtmap/estateplat/model/server/core/BdcCxBdcdyZt.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 *
 *持件列表
 * @author <a href="mailto:houqizheng@gtmap.cn">houqz</a>
 * @version 1.0, 2015/11/1
 */
@Table(name = "bdc_cx_bdcdy_zt")
public class BdcCxBdcdyZt implements Serializable {
    @Id
    private String ztid; //状态ID
    private String bdcdyh; //不动产单元号
    private String bdcdybh; //不动产单元编号
    private String bdclx; //不动产类型
    private String bdcdyzt; //不动产单元状态
    private String djzt; //登记状态
    private String qlr; //权利人
    private String zl; //坐落
    private Double mj; //面积
    private String yt; //用途
    private String cqzh; //产权证号
    private int zjgcdy; //在建工程抵押
    private int yg; //预告
    private int ydya; //预抵押
    private int dya; //抵押
    private int ycf; //预查封
    private int cf; //查封
    private int yy; //异议
    private int dyi; //地役
    private int sd; //锁定

    public String getZtid() {
        return ztid;
    }

    public void setZtid(String ztid) {
        this.ztid = ztid;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getBdclx() {
        return bdclx;
    }

    public void setBdclx(String bdclx) {
        this.bdclx = bdclx;
    }

    public String getBdcdyzt() {
        return bdcdyzt;
    }

    public void setBdcdyzt(String bdcdyzt) {
        this.bdcdyzt = bdcdyzt;
    }

    public String getDjzt() {
        return djzt;
    }

    public void setDjzt(String djzt) {
        this.djzt = djzt;
    }

    public String getQlr() {
        return qlr;
    }

    public void setQlr(String qlr) {
        this.qlr = qlr;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public Double getMj() {
        return mj;
    }

    public void setMj(Double mj) {
        this.mj = mj;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }

    public String getCqzh() {
        return cqzh;
    }

    public void setCqzh(String cqzh) {
        this.cqzh = cqzh;
    }

    public int getZjgcdy() {
        return zjgcdy;
    }

    public void setZjgcdy(int zjgcdy) {
        this.zjgcdy = zjgcdy;
    }

    public int getYg() {
        return yg;
    }

    public void setYg(int yg) {
        this.yg = yg;
    }

    public int getYdya() {
        return ydya;
    }

    public void setYdya(int ydya) {
        this.ydya = ydya;
    }

    public int getDya() {
        return dya;
    }

    public void setDya(int dya) {
        this.dya = dya;
    }

    public int getYcf() {
        return ycf;
    }

    public void setYcf(int ycf) {
        this.ycf = ycf;
    }

    public int getCf() {
        return cf;
    }

    public void setCf(int cf) {
        this.cf = cf;
    }

    public int getYy() {
        return yy;
    }

    public void setYy(int yy) {
        this.yy = yy;
    }

    public int getDyi() {
        return dyi;
    }

    public void setDyi(int dyi) {
        this.dyi = dyi;
    }

    public int getSd() {
        return sd;
    }

    public void setSd(int sd) {
        this.sd = sd;
    }
}

==> estateplat-common-1.2.4-20220125.064734-971-sources.jar: cn/gtmap/estateplat/model/server/core/BdcCxBdcdyZt.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 *
 *持件列表
 * @author <a href="mailto:houqizheng@gtmap.cn">houqz</a>
 * @version 1.0, 2015/11/1
 */
@Table(name = "bdc_cx_bdcdy_zt")
public class BdcCxBdcdyZt implements Serializable {
    @Id
    private String ztid; //状态ID
    private String bdcdyh; //不动产单元号
    private String bdcdybh; //不动产单元编号
    private String bdclx; //不动产类型
    private String bdcdyzt; //不动产单元状态
    private String djzt; //登记状态
    private String qlr; //权利人
    private String zl; //坐落
    private Double mj; //面积
    private String yt; //用途
    private String cqzh; //产权证号
    private int zjgcdy; //在建工程抵押
    private int yg; //预告
    private int ydya; //预抵押
    private int dya; //抵押
    private int ycf; //预查封
    private int cf; //查封
    private int yy; //异议
    private int dyi; //地役
    private int sd; //锁定
    private int ks; //可售
    private int ys; //预售

    public String getZtid() {
        return ztid;
    }

    public void setZtid(String ztid) {
        this.ztid = ztid;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getBdclx() {
        return bdclx;
    }

    public void setBdclx(String bdclx) {
        this.bdclx = bdclx;
    }

    public String getBdcdyzt() {
        return bdcdyzt;
    }

    public void setBdcdyzt(String bdcdyzt) {
        this.bdcdyzt = bdcdyzt;
    }

    public String getDjzt() {
        return djzt;
    }

    public void setDjzt(String djzt) {
        this.djzt = djzt;
    }

    public String getQlr() {
        return qlr;
    }

    public void setQlr(String qlr) {
        this.qlr = qlr;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public Double getMj() {
        return mj;
    }

    public void setMj(Double mj) {
        this.mj = mj;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }

    public String getCqzh() {
        return cqzh;
    }

    public void setCqzh(String cqzh) {
        this.cqzh = cqzh;
    }

    public int getZjgcdy() {
        return zjgcdy;
    }

    public void setZjgcdy(int zjgcdy) {
        this.zjgcdy = zjgcdy;
    }

    public int getYg() {
        return yg;
    }

    public void setYg(int yg) {
        this.yg = yg;
    }

    public int getYdya() {
        return ydya;
    }

    public void setYdya(int ydya) {
        this.ydya = ydya;
    }

    public int getDya() {
        return dya;
    }

    public void setDya(int dya) {
        this.dya = dya;
    }

    public int getYcf() {
        return ycf;
    }

    public void setYcf(int ycf) {
        this.ycf = ycf;
    }

    public int getCf() {
        return cf;
    }

    public void setCf(int cf) {
        this.cf = cf;
    }

    public int getYy() {
        return yy;
    }

    public void setYy(int yy) {
        this.yy = yy;
    }

    public int getDyi() {
        return dyi;
    }

    public void setDyi(int dyi) {
        this.dyi = dyi;
    }

    public int getSd() {
        return sd;
    }

    public void setSd(int sd) {
        this.sd = sd;
    }

    public int getKs() {
        return ks;
    }

    public void setKs(int ks) {
        this.ks = ks;
    }

    public int getYs() {
        return ys;
    }

    public void setYs(int ys) {
        this.ys = ys;
    }
}
